# Generated by roxygen2: do not edit by hand

export(OAuthClient)
export(OAuthProvider)
export(OAuthToken)
export(client_bearer_req)
export(custom_cache)
export(error_on_softened)
export(get_userinfo)
export(handle_callback)
export(introspect_token)
export(is_ok_host)
export(oauth_client)
export(oauth_client_mtls_registration)
export(oauth_form_post_ui)
export(oauth_module_server)
export(oauth_provider)
export(oauth_provider_auth0)
export(oauth_provider_github)
export(oauth_provider_google)
export(oauth_provider_keycloak)
export(oauth_provider_microsoft)
export(oauth_provider_oidc)
export(oauth_provider_oidc_discover)
export(oauth_provider_okta)
export(oauth_provider_slack)
export(oauth_provider_spotify)
export(perform_client_bearer_req)
export(perform_resource_req)
export(prepare_call)
export(refresh_token)
export(resource_req)
export(revoke_token)
export(use_shinyOAuth)
if (getRversion() < "4.3.0") importFrom("S7", "@")
import(S7)
import(httr2)
import(rlang)
importFrom(cli,cli_format)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(openssl,base64_encode)
importFrom(openssl,rand_bytes)
importFrom(openssl,sha256)
importFrom(stats,runif)
